#!perl -T

use Test::More tests => 1;

BEGIN {
	use_ok( 'Data::FormValidator::ErrMsgs::JavaScript' );
}

diag( "Testing Data::FormValidator::ErrMsgs::JavaScript $Data::FormValidator::ErrMsgs::JavaScript::VERSION, Perl $], $^X" );
